[Libreoffice-commits] core.git: basctl/source sc/source sfx2/source vcl/inc vcl/source

Tor Lillqvist tml at iki.fi
Tue Mar 12 00:47:42 PDT 2013


 basctl/source/basicide/baside2b.cxx |    6 ++---
 sc/source/filter/xml/xmlexprt.cxx   |    8 +++---
 sc/source/ui/app/inputwin.cxx       |    8 +++---
 sc/source/ui/inc/inputwin.hxx       |    6 ++---
 sc/source/ui/inc/navipi.hxx         |    4 +--
 sc/source/ui/inc/tphfedit.hxx       |    2 -
 sc/source/ui/navipi/navipi.cxx      |    4 +--
 sc/source/ui/navipi/scenwnd.cxx     |    4 +--
 sc/source/ui/pagedlg/tphfedit.cxx   |    6 ++---
 sc/source/ui/view/gridwin2.cxx      |    8 +++---
 sfx2/source/bastyp/sfxhtml.cxx      |    6 ++---
 vcl/inc/vcl/texteng.hxx             |    2 -
 vcl/source/edit/texteng.cxx         |   42 ++++++++++++++++++------------------
 vcl/source/edit/textview.cxx        |   28 ++++++++++++------------
 14 files changed, 67 insertions(+), 67 deletions(-)

New commits:
commit 5a2cfa677356f77cda15365dd9107ce503e11dd4
Author: Tor Lillqvist <tml at iki.fi>
Date:   Tue Mar 12 09:46:46 2013 +0200

    Abbreviate Rectangle as Rect, not Rec
    
    Change-Id: If38a5d23150bcd19a6eb6024c2ef1eea826898f5

diff --git a/basctl/source/basicide/baside2b.cxx b/basctl/source/basicide/baside2b.cxx
index ca6318f..e0fa872 100644
--- a/basctl/source/basicide/baside2b.cxx
+++ b/basctl/source/basicide/baside2b.cxx
@@ -918,10 +918,10 @@ void EditorWindow::ParagraphInsertedDeleted( sal_uLong nPara, bool bInserted )
 
         long nLineHeight = GetTextHeight();
         Size aSz = rModulWindow.GetBreakPointWindow().GetOutputSize();
-        Rectangle aInvRec( Point( 0, 0 ), aSz );
+        Rectangle aInvRect( Point( 0, 0 ), aSz );
         long nY = nPara*nLineHeight - rModulWindow.GetBreakPointWindow().GetCurYOffset();
-        aInvRec.Top() = nY;
-        rModulWindow.GetBreakPointWindow().Invalidate( aInvRec );
+        aInvRect.Top() = nY;
+        rModulWindow.GetBreakPointWindow().Invalidate( aInvRect );
 
         Size aLnSz(rModulWindow.GetLineNumberWindow().GetWidth(),
                    GetOutputSizePixel().Height() - 2 * DWBORDER);
diff --git a/sc/source/filter/xml/xmlexprt.cxx b/sc/source/filter/xml/xmlexprt.cxx
index 0e6e3f2..7d7be79 100644
--- a/sc/source/filter/xml/xmlexprt.cxx
+++ b/sc/source/filter/xml/xmlexprt.cxx
@@ -3137,14 +3137,14 @@ void ScXMLExport::WriteShapes(const ScMyCell& rMyCell)
     if( rMyCell.bHasShape && !rMyCell.aShapeList.empty() && pDoc )
     {
         awt::Point aPoint;
-        Rectangle aRec = pDoc->GetMMRect(static_cast<SCCOL>(rMyCell.aCellAddress.Column), static_cast<SCROW>(rMyCell.aCellAddress.Row),
+        Rectangle aRect = pDoc->GetMMRect(static_cast<SCCOL>(rMyCell.aCellAddress.Column), static_cast<SCROW>(rMyCell.aCellAddress.Row),
             static_cast<SCCOL>(rMyCell.aCellAddress.Column), static_cast<SCROW>(rMyCell.aCellAddress.Row), static_cast<SCTAB>(rMyCell.aCellAddress.Sheet));
         bool bNegativePage(pDoc->IsNegativePage(rMyCell.aCellAddress.Sheet));
         if (bNegativePage)
-            aPoint.X = aRec.Right();
+            aPoint.X = aRect.Right();
         else
-            aPoint.X = aRec.Left();
-        aPoint.Y = aRec.Top();
+            aPoint.X = aRect.Left();
+        aPoint.Y = aRect.Top();
         ScMyShapeList::const_iterator aItr = rMyCell.aShapeList.begin();
         ScMyShapeList::const_iterator aEndItr(rMyCell.aShapeList.end());
         while (aItr != aEndItr)
diff --git a/sc/source/ui/app/inputwin.cxx b/sc/source/ui/app/inputwin.cxx
index fb85f3d..6ada63d 100644
--- a/sc/source/ui/app/inputwin.cxx
+++ b/sc/source/ui/app/inputwin.cxx
@@ -1149,7 +1149,7 @@ ScMultiTextWnd::~ScMultiTextWnd()
 {
 }
 
-void ScMultiTextWnd::Paint( const Rectangle& rRec )
+void ScMultiTextWnd::Paint( const Rectangle& rRect )
 {
     EditView* pView = GetEditView();
     if ( pView )
@@ -1159,7 +1159,7 @@ void ScMultiTextWnd::Paint( const Rectangle& rRec )
             pView->Invalidate();
             mbInvalidate = false;
         }
-        pEditView->Paint( rRec );
+        pEditView->Paint( rRect );
     }
 }
 
@@ -1483,10 +1483,10 @@ ScTextWnd::~ScTextWnd()
     delete pEditEngine;
 }
 
-void ScTextWnd::Paint( const Rectangle& rRec )
+void ScTextWnd::Paint( const Rectangle& rRect )
 {
     if (pEditView)
-        pEditView->Paint( rRec );
+        pEditView->Paint( rRect );
     else
     {
         SetFont( aTextFont );
diff --git a/sc/source/ui/inc/inputwin.hxx b/sc/source/ui/inc/inputwin.hxx
index cec8377..8cd54f5 100644
--- a/sc/source/ui/inc/inputwin.hxx
+++ b/sc/source/ui/inc/inputwin.hxx
@@ -90,7 +90,7 @@ public:
     DECL_LINK( NotifyHdl, void* );
 
 protected:
-    virtual void    Paint( const Rectangle& rRec );
+    virtual void    Paint( const Rectangle& rRect );
     virtual void    Resize();
 
     virtual void    MouseMove( const MouseEvent& rMEvt );
@@ -187,7 +187,7 @@ protected:
     void SetScrollBarRange();
     void InitEditEngine();
 
-    virtual void Paint( const Rectangle& rRec );
+    virtual void Paint( const Rectangle& rRect );
     DECL_LINK( NotifyHdl, EENotify* );
     DECL_LINK( ModifyHdl, EENotify* );
 private:
@@ -207,7 +207,7 @@ public:
     virtual         ~ScInputBarGroup();
     virtual void            InsertAccessibleTextData( ScAccessibleEditLineTextData& rTextData );
     virtual void            RemoveAccessibleTextData( ScAccessibleEditLineTextData& rTextData );
-//    virtual void    Paint(const Rectangle& rRec );
+//    virtual void    Paint(const Rectangle& rRect );
     void            SetTextString( const String& rString );
     void            StartEditEngine();
     EditView*       GetEditView();
diff --git a/sc/source/ui/inc/navipi.hxx b/sc/source/ui/inc/navipi.hxx
index 9f45d2f..41eba60 100644
--- a/sc/source/ui/inc/navipi.hxx
+++ b/sc/source/ui/inc/navipi.hxx
@@ -111,7 +111,7 @@ public:
 
 protected:
 
-    virtual void    Paint( const Rectangle& rRec );
+    virtual void    Paint( const Rectangle& rRect );
 
 private:
     ScScenarioListBox   aLbScenario;
@@ -315,7 +315,7 @@ private:
 
 protected:
     virtual void    Resize();
-    virtual void    Paint( const Rectangle& rRec );
+    virtual void    Paint( const Rectangle& rRect );
     virtual void    Resizing( Size& rSize );
 
 public:
diff --git a/sc/source/ui/inc/tphfedit.hxx b/sc/source/ui/inc/tphfedit.hxx
index eade33b..79a38c5 100644
--- a/sc/source/ui/inc/tphfedit.hxx
+++ b/sc/source/ui/inc/tphfedit.hxx
@@ -73,7 +73,7 @@ public:
 
     inline ScHeaderEditEngine*  GetEditEngine() const {return pEdEngine;}
 protected:
-    virtual void    Paint( const Rectangle& rRec );
+    virtual void    Paint( const Rectangle& rRect );
     virtual void    MouseMove( const MouseEvent& rMEvt );
     virtual void    MouseButtonDown( const MouseEvent& rMEvt );
     virtual void    MouseButtonUp( const MouseEvent& rMEvt );
diff --git a/sc/source/ui/navipi/navipi.cxx b/sc/source/ui/navipi/navipi.cxx
index b5379a4..43ab289 100644
--- a/sc/source/ui/navipi/navipi.cxx
+++ b/sc/source/ui/navipi/navipi.cxx
@@ -768,7 +768,7 @@ void ScNavigatorDlg::Resizing( Size& rNewSize )  // Size = Outputsize?
 
 
 
-void ScNavigatorDlg::Paint( const Rectangle& rRec )
+void ScNavigatorDlg::Paint( const Rectangle& rRect )
 {
     const StyleSettings& rStyleSettings = Application::GetSettings().GetStyleSettings();
     Color aBgColor = rStyleSettings.GetFaceColor();
@@ -778,7 +778,7 @@ void ScNavigatorDlg::Paint( const Rectangle& rRec )
     aFtCol.SetBackground( aBack );
     aFtRow.SetBackground( aBack );
 
-    Window::Paint( rRec );
+    Window::Paint( rRect );
 }
 
 void ScNavigatorDlg::DataChanged( const DataChangedEvent& rDCEvt )
diff --git a/sc/source/ui/navipi/scenwnd.cxx b/sc/source/ui/navipi/scenwnd.cxx
index b2197b8..4ecce70 100644
--- a/sc/source/ui/navipi/scenwnd.cxx
+++ b/sc/source/ui/navipi/scenwnd.cxx
@@ -233,14 +233,14 @@ ScScenarioWindow::~ScScenarioWindow()
 {
 }
 
-void ScScenarioWindow::Paint( const Rectangle& rRec )
+void ScScenarioWindow::Paint( const Rectangle& rRect )
 {
     const StyleSettings& rStyleSettings = Application::GetSettings().GetStyleSettings();
     Color aBgColor = rStyleSettings.GetFaceColor();
 
     SetBackground( aBgColor );
 
-    Window::Paint( rRec );
+    Window::Paint( rRect );
 }
 
 // -----------------------------------------------------------------------
diff --git a/sc/source/ui/pagedlg/tphfedit.cxx b/sc/source/ui/pagedlg/tphfedit.cxx
index e7a9e3a..0ae46f3 100644
--- a/sc/source/ui/pagedlg/tphfedit.cxx
+++ b/sc/source/ui/pagedlg/tphfedit.cxx
@@ -221,7 +221,7 @@ void ScEditWindow::SetCharAttriutes()
 
 // -----------------------------------------------------------------------
 
-void ScEditWindow::Paint( const Rectangle& rRec )
+void ScEditWindow::Paint( const Rectangle& rRect )
 {
     const StyleSettings& rStyleSettings = Application::GetSettings().GetStyleSettings();
     Color aBgColor = rStyleSettings.GetWindowColor();
@@ -230,9 +230,9 @@ void ScEditWindow::Paint( const Rectangle& rRec )
 
     SetBackground( aBgColor );
 
-    Control::Paint( rRec );
+    Control::Paint( rRect );
 
-    pEdView->Paint( rRec );
+    pEdView->Paint( rRect );
 }
 
 // -----------------------------------------------------------------------
diff --git a/sc/source/ui/view/gridwin2.cxx b/sc/source/ui/view/gridwin2.cxx
index 79f2f08..150d385 100644
--- a/sc/source/ui/view/gridwin2.cxx
+++ b/sc/source/ui/view/gridwin2.cxx
@@ -136,8 +136,8 @@ bool ScGridWindow::DoAutoFilterButton( SCCOL nCol, SCROW nRow, const MouseEvent&
     Point aPopupPos;
     Size aPopupSize;
     mpFilterButton->getPopupBoundingBox(aPopupPos, aPopupSize);
-    Rectangle aRec(aPopupPos, aPopupSize);
-    if (aRec.IsInside(rMEvt.GetPosPixel()))
+    Rectangle aRect(aPopupPos, aPopupSize);
+    if (aRect.IsInside(rMEvt.GetPosPixel()))
     {
         if ( DoPageFieldSelection( nCol, nRow ) )
             return true;
@@ -374,8 +374,8 @@ bool ScGridWindow::DPTestFieldPopupArrow(
     Point aPopupPos;
     Size aPopupSize;
     aBtn.getPopupBoundingBox(aPopupPos, aPopupSize);
-    Rectangle aRec(aPopupPos, aPopupSize);
-    if (aRec.IsInside(rMEvt.GetPosPixel()))
+    Rectangle aRect(aPopupPos, aPopupSize);
+    if (aRect.IsInside(rMEvt.GetPosPixel()))
     {
         // Mouse cursor inside the popup arrow box.  Launch the field menu.
         DPLaunchFieldPopupMenu(OutputToScreenPixel(aScrPos), aScrSize, rDimPos, pDPObj);
diff --git a/sfx2/source/bastyp/sfxhtml.cxx b/sfx2/source/bastyp/sfxhtml.cxx
index 4fa1288f..c7d5dd8 100644
--- a/sfx2/source/bastyp/sfxhtml.cxx
+++ b/sfx2/source/bastyp/sfxhtml.cxx
@@ -183,9 +183,9 @@ IMAPOBJ_SETEVENT:
     case IMAP_OBJ_RECTANGLE:
         if( aCoords.size() >=4 )
         {
-            Rectangle aRec( aCoords[0], aCoords[1],
-                            aCoords[2], aCoords[3] );
-            IMapRectangleObject aMapRObj( aRec, aHRef, aAlt, String(), aTarget, aName,
+            Rectangle aRect( aCoords[0], aCoords[1],
+                             aCoords[2], aCoords[3] );
+            IMapRectangleObject aMapRObj( aRect, aHRef, aAlt, String(), aTarget, aName,
                                           !bNoHRef );
             if( !aMacroTbl.empty() )
                 aMapRObj.SetMacroTable( aMacroTbl );
diff --git a/vcl/inc/vcl/texteng.hxx b/vcl/inc/vcl/texteng.hxx
index 2fc0314..85b5a7b 100644
--- a/vcl/inc/vcl/texteng.hxx
+++ b/vcl/inc/vcl/texteng.hxx
@@ -104,7 +104,7 @@ private:
     ::com::sun::star::lang::Locale maLocale;
     ::com::sun::star::uno::Reference< ::com::sun::star::i18n::XBreakIterator > mxBreakIterator;
 
-    Rectangle           maInvalidRec;
+    Rectangle           maInvalidRect;
     Range               maInvalidRange;
 
     LocaleDataWrapper*  mpLocaleDataWrapper;
diff --git a/vcl/source/edit/textview.cxx b/vcl/source/edit/textview.cxx
index aa8a9d5..ff061bb 100644
--- a/vcl/source/edit/textview.cxx
+++ b/vcl/source/edit/textview.cxx
@@ -371,11 +371,11 @@ void TextView::ImpPaint( const Rectangle& rRect, sal_Bool bUseVirtDev )
             return;
         }
 
-        Rectangle aTmpRec( Point( 0, 0 ), rRect.GetSize() );
+        Rectangle aTmpRect( Point( 0, 0 ), rRect.GetSize() );
 
         Point aDocPos( mpImpl->maStartDocPos.X(), mpImpl->maStartDocPos.Y() + rRect.Top() );
         Point aStartPos = ImpGetOutputStartPos( aDocPos );
-        ImpPaint( pVDev, aStartPos, &aTmpRec, NULL, pDrawSelection );
+        ImpPaint( pVDev, aStartPos, &aTmpRect, NULL, pDrawSelection );
         mpImpl->mpWindow->DrawOutDev( rRect.TopLeft(), rRect.GetSize(),
                                 Point(0,0), rRect.GetSize(), *pVDev );
 //      ShowSelection();
@@ -435,15 +435,15 @@ void TextView::ImpHighlight( const TextSelection& rSel )
                     if ( nEndIndex < nStartIndex )
                         nEndIndex = nStartIndex;
 
-                    Rectangle aTmpRec( mpImpl->mpTextEngine->GetEditCursor( TextPaM( nPara, nStartIndex ), sal_False ) );
-                    aTmpRec.Top() += nY;
-                    aTmpRec.Bottom() += nY;
-                    Point aTopLeft( aTmpRec.TopLeft() );
+                    Rectangle aTmpRect( mpImpl->mpTextEngine->GetEditCursor( TextPaM( nPara, nStartIndex ), sal_False ) );
+                    aTmpRect.Top() += nY;
+                    aTmpRect.Bottom() += nY;
+                    Point aTopLeft( aTmpRect.TopLeft() );
 
-                    aTmpRec = mpImpl->mpTextEngine->GetEditCursor( TextPaM( nPara, nEndIndex ), sal_True );
-                    aTmpRec.Top() += nY;
-                    aTmpRec.Bottom() += nY;
-                    Point aBottomRight( aTmpRec.BottomRight() );
+                    aTmpRect = mpImpl->mpTextEngine->GetEditCursor( TextPaM( nPara, nEndIndex ), sal_True );
+                    aTmpRect.Top() += nY;
+                    aTmpRect.Bottom() += nY;
+                    Point aBottomRight( aTmpRect.BottomRight() );
                     aBottomRight.X()--;
 
                     // Nur Painten, wenn im sichtbaren Bereich...
@@ -1682,8 +1682,8 @@ TextPaM TextView::CursorEndOfDoc()
 
 TextPaM TextView::PageUp( const TextPaM& rPaM )
 {
-    Rectangle aRec = mpImpl->mpTextEngine->PaMtoEditCursor( rPaM );
-    Point aTopLeft = aRec.TopLeft();
+    Rectangle aRect = mpImpl->mpTextEngine->PaMtoEditCursor( rPaM );
+    Point aTopLeft = aRect.TopLeft();
     aTopLeft.Y() -= mpImpl->mpWindow->GetOutputSizePixel().Height() * 9/10;
     aTopLeft.X() += 1;
     if ( aTopLeft.Y() < 0 )
@@ -1695,8 +1695,8 @@ TextPaM TextView::PageUp( const TextPaM& rPaM )
 
 TextPaM TextView::PageDown( const TextPaM& rPaM )
 {
-    Rectangle aRec = mpImpl->mpTextEngine->PaMtoEditCursor( rPaM );
-    Point aBottomRight = aRec.BottomRight();
+    Rectangle aRect = mpImpl->mpTextEngine->PaMtoEditCursor( rPaM );
+    Point aBottomRight = aRect.BottomRight();
     aBottomRight.Y() += mpImpl->mpWindow->GetOutputSizePixel().Height() * 9/10;
     aBottomRight.X() += 1;
     long nHeight = mpImpl->mpTextEngine->GetTextHeight();


More information about the Libreoffice-commits mailing list
diff --git a/vcl/source/edit/texteng.cxx b/vcl/source/edit/texteng.cxx
index 487d83e..2372768 100644
--- a/vcl/source/edit/texteng.cxx
+++ b/vcl/source/edit/texteng.cxx
@@ -1507,7 +1507,7 @@ void TextEngine::TextModified()
 
 void TextEngine::UpdateViews( TextView* pCurView )
 {
-    if ( !GetUpdateMode() || IsFormatting() || maInvalidRec.IsEmpty() )
+    if ( !GetUpdateMode() || IsFormatting() || maInvalidRect.IsEmpty() )
         return;
 
     DBG_ASSERT( IsFormatted(), "UpdateViews: Doc nicht formatiert!" );
@@ -1517,22 +1517,22 @@ void TextEngine::UpdateViews( TextView* pCurView )
         TextView* pView = (*mpViews)[ nView ];
         pView->HideCursor();
 
-        Rectangle aClipRec( maInvalidRec );
+        Rectangle aClipRect( maInvalidRect );
         Size aOutSz = pView->GetWindow()->GetOutputSizePixel();
         Rectangle aVisArea( pView->GetStartDocPos(), aOutSz );
-        aClipRec.Intersection( aVisArea );
-        if ( !aClipRec.IsEmpty() )
+        aClipRect.Intersection( aVisArea );
+        if ( !aClipRect.IsEmpty() )
         {
             // in Fensterkoordinaten umwandeln....
-            Point aNewPos = pView->GetWindowPos( aClipRec.TopLeft() );
+            Point aNewPos = pView->GetWindowPos( aClipRect.TopLeft() );
             if ( IsRightToLeft() )
                 aNewPos.X() -= aOutSz.Width() - 1;
-            aClipRec.SetPos( aNewPos );
+            aClipRect.SetPos( aNewPos );
 
             if ( pView == pCurView )
-                pView->ImpPaint( aClipRec, !pView->GetWindow()->IsPaintTransparent() );
+                pView->ImpPaint( aClipRect, !pView->GetWindow()->IsPaintTransparent() );
             else
-                pView->GetWindow()->Invalidate( aClipRec );
+                pView->GetWindow()->Invalidate( aClipRect );
         }
     }
 
@@ -1541,7 +1541,7 @@ void TextEngine::UpdateViews( TextView* pCurView )
         pCurView->ShowCursor( pCurView->IsAutoScroll() );
     }
 
-    maInvalidRec = Rectangle();
+    maInvalidRect = Rectangle();
 }
 
 IMPL_LINK_NOARG(TextEngine, IdleFormatHdl)
@@ -1577,7 +1577,7 @@ void TextEngine::FormatDoc()
     long nY = 0;
     sal_Bool bGrow = sal_False;
 
-    maInvalidRec = Rectangle(); // leermachen
+    maInvalidRect = Rectangle(); // leermachen
     for ( sal_uLong nPara = 0; nPara < mpTEParaPortions->Count(); nPara++ )
     {
         TEParaPortion* pTEParaPortion = mpTEParaPortions->GetObject( nPara );
@@ -1592,20 +1592,20 @@ void TextEngine::FormatDoc()
             if ( CreateLines( nPara ) )
                 bGrow = sal_True;
 
-            // InvalidRec nur einmal setzen...
-            if ( maInvalidRec.IsEmpty() )
+            // InvalidRect nur einmal setzen...
+            if ( maInvalidRect.IsEmpty() )
             {
                 // Bei Paperwidth 0 (AutoPageSize) bleibt es sonst Empty()...
                 long nWidth = (long)mnMaxTextWidth;
                 if ( !nWidth )
                     nWidth = 0x7FFFFFFF;
                 Range aInvRange( GetInvalidYOffsets( nPara ) );
-                maInvalidRec = Rectangle( Point( 0, nY+aInvRange.Min() ),
+                maInvalidRect = Rectangle( Point( 0, nY+aInvRange.Min() ),
                     Size( nWidth, aInvRange.Len() ) );
             }
             else
             {
-                maInvalidRec.Bottom() = nY + CalcParaHeight( nPara );
+                maInvalidRect.Bottom() = nY + CalcParaHeight( nPara );
             }
 
             if ( mnCurTextWidth != 0xFFFFFFFF )
@@ -1619,26 +1619,26 @@ void TextEngine::FormatDoc()
         }
         else if ( bGrow )
         {
-            maInvalidRec.Bottom() = nY + CalcParaHeight( nPara );
+            maInvalidRect.Bottom() = nY + CalcParaHeight( nPara );
         }
         nY += CalcParaHeight( nPara );
         if ( !mbHasMultiLineParas && pTEParaPortion->GetLines().size() > 1 )
             mbHasMultiLineParas = sal_True;
     }
 
-    if ( !maInvalidRec.IsEmpty() )
+    if ( !maInvalidRect.IsEmpty() )
     {
         sal_uLong nNewHeight = CalcTextHeight();
         long nDiff = nNewHeight - mnCurTextHeight;
         if ( nNewHeight < mnCurTextHeight )
         {
-            maInvalidRec.Bottom() = (long)Max( nNewHeight, mnCurTextHeight );
-            if ( maInvalidRec.IsEmpty() )
+            maInvalidRect.Bottom() = (long)Max( nNewHeight, mnCurTextHeight );
+            if ( maInvalidRect.IsEmpty() )
             {
-                maInvalidRec.Top() = 0;
+                maInvalidRect.Top() = 0;
                 // Left und Right werden nicht ausgewertet, aber wegen IsEmpty gesetzt.
-                maInvalidRec.Left() = 0;
-                maInvalidRec.Right() = mnMaxTextWidth;
+                maInvalidRect.Left() = 0;
+                maInvalidRect.Right() = mnMaxTextWidth;
             }
         }
 